@@ -69,23 +69,23 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     }
     let sel = rconfig.selection(&headers)?;
 
-    let mut new: Vec<_> = vec![];
+    let mut all = rdr.byte_records().collect::<Result<Vec<_>, _>>()?;
+    all.sort_unstable_by(|r1, r2| {
+        let a = sel.select(r1);
+        let b = sel.select(r2);
+        iter_cmp(a, b)
+    });
+
+    rconfig.write_headers(&mut rdr, &mut wtr)?;
     let mut dupe_count = 0_usize;
     {
-        let mut all = rdr.byte_records().collect::<Result<Vec<_>, _>>()?;
-        all.sort_by(|r1, r2| {
-            let a = sel.select(r1);
-            let b = sel.select(r2);
-            iter_cmp(a, b)
-        });
-
         let mut current = 0;
         while current + 1 < all.len() {
             let a = sel.select(&all[current]);
             let b = sel.select(&all[current + 1]);
             if no_case {
                 if iter_cmp_no_case(a, b) != cmp::Ordering::Equal {
-                    new.push(all[current].clone());
+                    wtr.write_byte_record(&all[current])?;
                 } else {
                     dupe_count += 1;
                     if dupes_output {
@@ -93,7 +93,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                     }
                 }
             } else if iter_cmp(a, b) != cmp::Ordering::Equal {
-                new.push(all[current].clone());
+                wtr.write_byte_record(&all[current])?;
             } else {
                 dupe_count += 1;
                 if dupes_output {
@@ -102,14 +102,10 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             }
             current += 1;
         }
-        new.push(all[current].clone());
+        wtr.write_byte_record(&all[current])?;
     }
 
     dupewtr.flush()?;
-    rconfig.write_headers(&mut rdr, &mut wtr)?;
-    for r in new {
-        wtr.write_byte_record(&r)?;
-    }
 
     if args.flag_human_readable {
         use thousands::Separable;
